# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pydatafaker']

package_data = \
{'': ['*']}

install_requires = \
['faker>=4.1.2,<5.0.0', 'pandas>=1.1.1,<2.0.0']

setup_kwargs = {
    'name': 'pydatafaker',
    'version': '0.1.1a3',
    'description': 'A python package to create fake data with relationships between tables.',
    'long_description': "\n# PyDataFaker\n\n![test\\_with\\_pytest](https://github.com/SamEdwardes/pydatafaker/workflows/test_with_pytest/badge.svg)\n[![Documentation\nStatus](https://readthedocs.org/projects/pydatafaker/badge/?version=latest)](https://pydatafaker.readthedocs.io/en/latest/?badge=latest)\n\nPyDataFaker is a python package to create fake data with relationships\nbetween tables. Creating fake data can be useful for many different\napplications such as creating product demos or testing software.\n\nPython already has a great package for creating fake data called Faker\n<https://faker.readthedocs.io/en/master/>. Faker is great for creating\nindividual fake units of data, but it can be time consuming to create\nmore complicated fake data that is actually related to one another.\n\nImagine you are developing a new enterprise resource planning (ERP)\nsoftware to challenge SAP. You may need to create some fake data to test\nyour application. You will need an invoice table, a vendor listing,\npurchase order table, and more. PyDataFaker allows your to quickly\ncreate these tables and generates relationships between them\\!\n\nPyDataFaker is currently under development. At this time it is possible\nto create the following entities:\n\n  - **Business**: create a fake business with common ERP like tables\n  - **School**: create a fake school\n\nMore entities are currently being developed. If you have any ideas of\nadditional entities that should be included please submit an issue here:\n<https://github.com/SamEdwardes/pydatafaker/issues>.\n\n## Table of contents\n\n  - [Installation](#installation)\n  - [Documentation](#documentation)\n  - [Usage](#usage)\n  - [Contributing](#contributing)\n  - [Credits](#credits)\n\n## Installation\n\n``` bash\npip install pydatafaker\n```\n\n## Documentation\n\nDocumentation can be found at\n<https://pydatafaker.readthedocs.io/en/latest/index.html>. The package\nis distributed through PyPi at <https://pypi.org/project/pydatafaker/>\n\n## Usage\n\n### Business\n\nThe business module allows you to create fake business data. Calling\n`business.create_business()` will return a dictionary of related tables.\n\n``` python\nimport pandas as pd\nfrom pydatafaker import business\nbiz =  business.create_business()\nbiz.keys()\n```\n\n    ## dict_keys(['vendor_table', 'po_table', 'invoice_summary_table', 'invoice_line_item_table', 'employee_table', 'contract_table', 'rate_sheet_table', 'timesheet_table'])\n\nEach value inside the dictionary contains a Pandas DataFrame.\n\n``` python\nbiz['invoice_summary_table']\n```\n\n    ##     invoice_id  amount invoice_date     po_id     vendor_id\n    ## 0    inv_00001  113523   2007-03-03  po_00054  vendor_00056\n    ## 1    inv_00002  138918   2015-12-10  po_00082  vendor_00005\n    ## 2    inv_00003   74733   2016-12-11  po_00056  vendor_00095\n    ## 3    inv_00004   94950   2003-02-04  po_00012  vendor_00085\n    ## 4    inv_00005   65429   2010-09-08  po_00060  vendor_00078\n    ## ..         ...     ...          ...       ...           ...\n    ## 245  inv_00246  124564   2000-05-08  po_00010  vendor_00068\n    ## 246  inv_00247  108703   2013-01-15  po_00099  vendor_00072\n    ## 247  inv_00248  124734   2014-12-16  po_00079  vendor_00051\n    ## 248  inv_00249  100626   2016-08-02  po_00047  vendor_00052\n    ## 249  inv_00250   75489   2004-10-13  po_00047  vendor_00052\n    ## \n    ## [250 rows x 5 columns]\n\nTables can be joined together to add additional details.\n\n``` python\ninvoice_summary = biz['invoice_summary_table']\nvendors = biz['vendor_table']\n\npd.merge(invoice_summary, vendors, how='left', on='vendor_id')\n```\n\n    ##     invoice_id  amount  ...                 phone                     email\n    ## 0    inv_00001  113523  ...  001-828-249-6157x408  nicholashuff@example.org\n    ## 1    inv_00002  138918  ...          859.096.2158   elizabeth66@example.org\n    ## 2    inv_00003   74733  ...  +1-464-465-9562x0288  sarahbennett@example.com\n    ## 3    inv_00004   94950  ...      001-513-424-8491   zacharyyang@example.org\n    ## 4    inv_00005   65429  ...         (482)058-1418      denise65@example.org\n    ## ..         ...     ...  ...                   ...                       ...\n    ## 245  inv_00246  124564  ...          195-749-4878          vmay@example.net\n    ## 246  inv_00247  108703  ...  001-968-278-4877x690   brianmacias@example.org\n    ## 247  inv_00248  124734  ...      730.130.8577x132       qsnyder@example.net\n    ## 248  inv_00249  100626  ...         (272)217-8221       vicki33@example.org\n    ## 249  inv_00250   75489  ...         (272)217-8221       vicki33@example.org\n    ## \n    ## [250 rows x 10 columns]\n\n### School\n\n``` python\nimport pandas as pd\nfrom pydatafaker import school\nskool =  school.create_school()\nskool.keys()\n```\n\n    ## dict_keys(['student_table', 'teacher_table', 'room_table'])\n\n``` python\nskool['student_table']\n```\n\n    ##       student_id                  name  grade    teacher_id\n    ## 0   student_0001       Christopher Ray      1  teacher_0011\n    ## 1   student_0002          Henry Jacobs      1  teacher_0011\n    ## 2   student_0004           Brenda Mays      1  teacher_0010\n    ## 3   student_0019          Laura Thomas      1  teacher_0011\n    ## 4   student_0022         Philip Taylor      1  teacher_0010\n    ## ..           ...                   ...    ...           ...\n    ## 33  student_0263        Wesley Johnson      7  teacher_0012\n    ## 34  student_0266        Jennifer Reyes      7  teacher_0012\n    ## 35  student_0276    Abigail Cunningham      7  teacher_0016\n    ## 36  student_0283  Christina Fitzgerald      7  teacher_0012\n    ## 37  student_0288       Mr. Walter Rios      7  teacher_0012\n    ## \n    ## [300 rows x 4 columns]\n\n## Contributing\n\nPlease see [docs/source/contributing.rst](docs/source/contributing.rst).\n\n## Credits\n\nDeveloped by:\n\n  - Sam Edwardes\n\nLogo:\n\n  - Icon made by [Freepik](https://www.flaticon.com/authors/freepik)\n    from [www.flaticon.com](https://www.flaticon.com/)\n  - Front from\n    [fontmeme.com/retro-fonts/](https://fontmeme.com/retro-fonts/)\n  - Logo generated using [logomakr.com](logomakr.com/7scB4)\n",
    'author': 'Sam Edwardes',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/SamEdwardes/pydatafaker',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
